@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import ExperimentActionStatusType, ExperimentStatusType
 
@@ -29,10 +29,12 @@ __all__ = (
     "ActionTargetTypeDef",
     "ActionTypeDef",
     "CreateExperimentTemplateActionInputTypeDef",
-    "CreateExperimentTemplateResponseTypeDef",
+    "CreateExperimentTemplateRequestTypeDef",
+    "CreateExperimentTemplateResponseResponseTypeDef",
     "CreateExperimentTemplateStopConditionInputTypeDef",
     "CreateExperimentTemplateTargetInputTypeDef",
-    "DeleteExperimentTemplateResponseTypeDef",
+    "DeleteExperimentTemplateRequestTypeDef",
+    "DeleteExperimentTemplateResponseResponseTypeDef",
     "ExperimentActionStateTypeDef",
     "ExperimentActionTypeDef",
     "ExperimentStateTypeDef",
@@ -48,17 +50,30 @@ __all__ = (
     "ExperimentTemplateTargetTypeDef",
     "ExperimentTemplateTypeDef",
     "ExperimentTypeDef",
-    "GetActionResponseTypeDef",
-    "GetExperimentResponseTypeDef",
-    "GetExperimentTemplateResponseTypeDef",
-    "ListActionsResponseTypeDef",
-    "ListExperimentTemplatesResponseTypeDef",
-    "ListExperimentsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "StartExperimentResponseTypeDef",
-    "StopExperimentResponseTypeDef",
+    "GetActionRequestTypeDef",
+    "GetActionResponseResponseTypeDef",
+    "GetExperimentRequestTypeDef",
+    "GetExperimentResponseResponseTypeDef",
+    "GetExperimentTemplateRequestTypeDef",
+    "GetExperimentTemplateResponseResponseTypeDef",
+    "ListActionsRequestTypeDef",
+    "ListActionsResponseResponseTypeDef",
+    "ListExperimentTemplatesRequestTypeDef",
+    "ListExperimentTemplatesResponseResponseTypeDef",
+    "ListExperimentsRequestTypeDef",
+    "ListExperimentsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "StartExperimentRequestTypeDef",
+    "StartExperimentResponseResponseTypeDef",
+    "StopExperimentRequestTypeDef",
+    "StopExperimentResponseResponseTypeDef",
+    "TagResourceRequestTypeDef",
+    "UntagResourceRequestTypeDef",
     "UpdateExperimentTemplateActionInputItemTypeDef",
-    "UpdateExperimentTemplateResponseTypeDef",
+    "UpdateExperimentTemplateRequestTypeDef",
+    "UpdateExperimentTemplateResponseResponseTypeDef",
     "UpdateExperimentTemplateStopConditionInputTypeDef",
     "UpdateExperimentTemplateTargetInputTypeDef",
 )
@@ -128,14 +143,40 @@ class CreateExperimentTemplateActionInputTypeDef(
     pass
 
 
-CreateExperimentTemplateResponseTypeDef = TypedDict(
-    "CreateExperimentTemplateResponseTypeDef",
+_RequiredCreateExperimentTemplateRequestTypeDef = TypedDict(
+    "_RequiredCreateExperimentTemplateRequestTypeDef",
     {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
+        "clientToken": str,
+        "description": str,
+        "stopConditions": List["CreateExperimentTemplateStopConditionInputTypeDef"],
+        "actions": Dict[str, "CreateExperimentTemplateActionInputTypeDef"],
+        "roleArn": str,
+    },
+)
+_OptionalCreateExperimentTemplateRequestTypeDef = TypedDict(
+    "_OptionalCreateExperimentTemplateRequestTypeDef",
+    {
+        "targets": Dict[str, "CreateExperimentTemplateTargetInputTypeDef"],
+        "tags": Dict[str, str],
     },
     total=False,
 )
 
+
+class CreateExperimentTemplateRequestTypeDef(
+    _RequiredCreateExperimentTemplateRequestTypeDef, _OptionalCreateExperimentTemplateRequestTypeDef
+):
+    pass
+
+
+CreateExperimentTemplateResponseResponseTypeDef = TypedDict(
+    "CreateExperimentTemplateResponseResponseTypeDef",
+    {
+        "experimentTemplate": "ExperimentTemplateTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateExperimentTemplateStopConditionInputTypeDef = TypedDict(
     "_RequiredCreateExperimentTemplateStopConditionInputTypeDef",
     {
@@ -183,12 +224,19 @@ class CreateExperimentTemplateTargetInputTypeDef(
     pass
 
 
-DeleteExperimentTemplateResponseTypeDef = TypedDict(
-    "DeleteExperimentTemplateResponseTypeDef",
+DeleteExperimentTemplateRequestTypeDef = TypedDict(
+    "DeleteExperimentTemplateRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+DeleteExperimentTemplateResponseResponseTypeDef = TypedDict(
+    "DeleteExperimentTemplateResponseResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 ExperimentActionStateTypeDef = TypedDict(
@@ -360,80 +408,204 @@ ExperimentTypeDef = TypedDict(
     total=False,
 )
 
-GetActionResponseTypeDef = TypedDict(
-    "GetActionResponseTypeDef",
+GetActionRequestTypeDef = TypedDict(
+    "GetActionRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+GetActionResponseResponseTypeDef = TypedDict(
+    "GetActionResponseResponseTypeDef",
     {
         "action": "ActionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetExperimentResponseTypeDef = TypedDict(
-    "GetExperimentResponseTypeDef",
+GetExperimentRequestTypeDef = TypedDict(
+    "GetExperimentRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+GetExperimentResponseResponseTypeDef = TypedDict(
+    "GetExperimentResponseResponseTypeDef",
     {
         "experiment": "ExperimentTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetExperimentTemplateResponseTypeDef = TypedDict(
-    "GetExperimentTemplateResponseTypeDef",
+GetExperimentTemplateRequestTypeDef = TypedDict(
+    "GetExperimentTemplateRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+GetExperimentTemplateResponseResponseTypeDef = TypedDict(
+    "GetExperimentTemplateResponseResponseTypeDef",
     {
         "experimentTemplate": "ExperimentTemplateTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListActionsRequestTypeDef = TypedDict(
+    "ListActionsRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
 
-ListActionsResponseTypeDef = TypedDict(
-    "ListActionsResponseTypeDef",
+ListActionsResponseResponseTypeDef = TypedDict(
+    "ListActionsResponseResponseTypeDef",
     {
         "actions": List["ActionSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListExperimentTemplatesRequestTypeDef = TypedDict(
+    "ListExperimentTemplatesRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
     },
     total=False,
 )
 
-ListExperimentTemplatesResponseTypeDef = TypedDict(
-    "ListExperimentTemplatesResponseTypeDef",
+ListExperimentTemplatesResponseResponseTypeDef = TypedDict(
+    "ListExperimentTemplatesResponseResponseTypeDef",
     {
         "experimentTemplates": List["ExperimentTemplateSummaryTypeDef"],
         "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListExperimentsResponseTypeDef = TypedDict(
-    "ListExperimentsResponseTypeDef",
+ListExperimentsRequestTypeDef = TypedDict(
+    "ListExperimentsRequestTypeDef",
     {
-        "experiments": List["ExperimentSummaryTypeDef"],
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListExperimentsResponseResponseTypeDef = TypedDict(
+    "ListExperimentsResponseResponseTypeDef",
+    {
+        "experiments": List["ExperimentSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
+_RequiredStartExperimentRequestTypeDef = TypedDict(
+    "_RequiredStartExperimentRequestTypeDef",
+    {
+        "clientToken": str,
+        "experimentTemplateId": str,
+    },
+)
+_OptionalStartExperimentRequestTypeDef = TypedDict(
+    "_OptionalStartExperimentRequestTypeDef",
     {
         "tags": Dict[str, str],
     },
     total=False,
 )
 
-StartExperimentResponseTypeDef = TypedDict(
-    "StartExperimentResponseTypeDef",
+
+class StartExperimentRequestTypeDef(
+    _RequiredStartExperimentRequestTypeDef, _OptionalStartExperimentRequestTypeDef
+):
+    pass
+
+
+StartExperimentResponseResponseTypeDef = TypedDict(
+    "StartExperimentResponseResponseTypeDef",
     {
         "experiment": "ExperimentTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopExperimentRequestTypeDef = TypedDict(
+    "StopExperimentRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
+StopExperimentResponseResponseTypeDef = TypedDict(
+    "StopExperimentResponseResponseTypeDef",
+    {
+        "experiment": "ExperimentTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
+_RequiredUntagResourceRequestTypeDef = TypedDict(
+    "_RequiredUntagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+_OptionalUntagResourceRequestTypeDef = TypedDict(
+    "_OptionalUntagResourceRequestTypeDef",
+    {
+        "tagKeys": List[str],
     },
     total=False,
 )
 
-StopExperimentResponseTypeDef = TypedDict(
-    "StopExperimentResponseTypeDef",
-    {
-        "experiment": "ExperimentTypeDef",
-    },
-    total=False,
-)
+
+class UntagResourceRequestTypeDef(
+    _RequiredUntagResourceRequestTypeDef, _OptionalUntagResourceRequestTypeDef
+):
+    pass
+
 
 UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     "UpdateExperimentTemplateActionInputItemTypeDef",
@@ -447,14 +619,39 @@ UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     total=False,
 )
 
-UpdateExperimentTemplateResponseTypeDef = TypedDict(
-    "UpdateExperimentTemplateResponseTypeDef",
+_RequiredUpdateExperimentTemplateRequestTypeDef = TypedDict(
+    "_RequiredUpdateExperimentTemplateRequestTypeDef",
     {
-        "experimentTemplate": "ExperimentTemplateTypeDef",
+        "id": str,
+    },
+)
+_OptionalUpdateExperimentTemplateRequestTypeDef = TypedDict(
+    "_OptionalUpdateExperimentTemplateRequestTypeDef",
+    {
+        "description": str,
+        "stopConditions": List["UpdateExperimentTemplateStopConditionInputTypeDef"],
+        "targets": Dict[str, "UpdateExperimentTemplateTargetInputTypeDef"],
+        "actions": Dict[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
+        "roleArn": str,
     },
     total=False,
 )
 
+
+class UpdateExperimentTemplateRequestTypeDef(
+    _RequiredUpdateExperimentTemplateRequestTypeDef, _OptionalUpdateExperimentTemplateRequestTypeDef
+):
+    pass
+
+
+UpdateExperimentTemplateResponseResponseTypeDef = TypedDict(
+    "UpdateExperimentTemplateResponseResponseTypeDef",
+    {
+        "experimentTemplate": "ExperimentTemplateTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateExperimentTemplateStopConditionInputTypeDef = TypedDict(
     "_RequiredUpdateExperimentTemplateStopConditionInputTypeDef",
     {
